@echo off

if not exist gpg.exe goto gpgnotfound
if exist secring.gpg goto alreadycreated
if exist pubring.gpg goto alreadycreated

del /q /f trustdb.gpg gpgviewkey.txt 2>nul

echo.
echo +------------------------------------------------------------------+
echo I                                                                  I
echo I    Creating a new GPG key.                                       I
echo I                                                                  I
echo I    This procedure will create a new GPG key for you.             I
echo I    Please follow the GPG prompts to create the new key.          I
echo I                                                                  I
echo I    You should use a "DSA and Elgamal" key (option [1]), which    I
echo I    is the default option. The key size should be 2048, which     I
echo I    is also the default option. Then, you may select [0] to       I
echo I    create a key that will not expire. You must confirm that      I
echo I    by pressing "y" (for "yes") on the next prompt.               I
echo I                                                                  I
echo I    GPG will then ask you for your name and e-mail. Please        I
echo I    fill that information in. The "Comment" field may be left     I
echo I    blank. Confirm the information with "o" (for "Okay").         I
echo I                                                                  I
echo I    Then enter your passphrase. Please use a passphrase that      I
echo I    is long enough. When GPG is generating your key, you might    I
echo I    need to move your mouse or use other programs so that GPG     I
echo I    can get enough randomness to generate your key.               I
echo I                                                                  I
echo +------------------------------------------------------------------+
pause

gpg --homedir . --gen-key
if not errorlevel 0 goto errorgenkey
del /q *.bak 2>nul

echo.
echo +------------------------------------------------------------------+
echo I                                                                  I
echo I    Your key was successfully generated.                          I
echo I                                                                  I
echo I    Now your key will be exported so that you can send it by      I
echo I    e-mail to someone that will encrypt files for you to read.    I
echo I                                                                  I
echo +------------------------------------------------------------------+
echo.

gpg --homedir . --export -a -o gpgviewkey.txt
if not errorlevel 0 goto errorexportkey

echo.
echo +------------------------------------------------------------------+
echo I                                                                  I
echo I    Your key was successfully exported.                           I
echo I                                                                  I
echo I    You may now send the [gpgviewkey.txt] file in the             I
echo I    [gpgview\gnupg] directory for others to encrypt files         I
echo I    for you to read.                                              I
echo I                                                                  I
echo +------------------------------------------------------------------+
goto end



:errorgenkey
del /q *.bak 2>nul
del /q secring.gpg pubring.gpg trustdb.gpg 2>nul
echo.
echo +------------------------------------------------------------------+
echo I                                                                  I
echo I    ERROR! There was an error running GPG to create your key.     I
echo I                                                                  I
echo I    Please check the above error messages.                        I
echo I                                                                  I
echo +------------------------------------------------------------------+
goto end


:errorexportkey
del /q *.bak 2>nul
del /q secring.gpg pubring.gpg trustdb.gpg gpgviewkey.txt 2>nul
echo.
echo +------------------------------------------------------------------+
echo I                                                                  I
echo I    ERROR! There was an error running GPG to export your key.     I
echo I                                                                  I
echo I    Please check the above error messages.                        I
echo I    Please note that the key was deleted.                         I
echo I                                                                  I
echo +------------------------------------------------------------------+
goto end


:gpgnotfound
echo.
echo +------------------------------------------------------------------+
echo I                                                                  I
echo I    ERROR! Could not found [gpg.exe] file.                        I
echo I                                                                  I
echo I    Please check your installation, and make sure you are         I
echo I    running this batch file in the [gpgview\gnupg] directory.     I
echo I                                                                  I
echo +------------------------------------------------------------------+
goto end


:alreadycreated
echo.
echo +------------------------------------------------------------------+
echo I                                                                  I
echo I    WARNING! A key was already created.                           I
echo I                                                                  I
echo I    If you really want to create a new key, you must delete       I
echo I    your old one first. For that, please delete the [*.gpg]       I
echo I    files (secring.gpg, pubring.gpg and trustdb.gpg) in the       I
echo I    [gpgview\gnupg] directory before running this script.         I
echo I                                                                  I
echo +------------------------------------------------------------------+
goto end


:end
pause

